@@ -1,21 +1,8 @@
 /*
-    Copyright (c) 2019 Eike Hein <hein@kde.org>
-    Copyright (C) 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
+    SPDX-FileCopyrightText: 2019 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
@@ -70,6 +57,12 @@ class SENSORS_EXPORT SensorDataModel : public QAbstractTableModel, public QQmlPa
      * Used by the model to provide data for the Color role if set.
      */
     Q_PROPERTY(QVariantMap sensorColors READ sensorColors WRITE setSensorColors NOTIFY sensorColorsChanged)
+
+    /**
+     * Provides custom labels for Sensors that are used instead of the name and short name of the sensors.
+     */
+    Q_PROPERTY(QVariantMap sensorLabels READ sensorLabels WRITE setSensorLabels NOTIFY sensorLabelsChanged)
+
     /**
      * The minimum time between updates, in milliseconds.
      *
@@ -87,17 +80,17 @@ public:
      */
     enum AdditionalRoles {
         SensorId = Qt::UserRole + 1, ///< The backend path to the sensor.
-        Name,                        ///< The name of the sensor.
-        ShortName,                   ///< A shorter name for the sensor. This is equal to name if not set.
-        Description,                 ///< A description for the sensor.
-        Unit,                        ///< The unit of the sensor.
-        Minimum,                     ///< The minimum value this sensor can have.
-        Maximum,                     ///< The maximum value this sensor can have.
-        Type,                        ///< The QVariant::Type of the sensor.
-        Value,                       ///< The value of the sensor.
-        FormattedValue,              ///< A formatted string of the value of the sensor.
-        Color,                       ///< A color of the sensor, if sensorColors is set
-        UpdateInterval,              ///< The time in milliseconds between each update of the sensor.
+        Name, ///< The name of the sensor.
+        ShortName, ///< A shorter name for the sensor. This is equal to name if not set.
+        Description, ///< A description for the sensor.
+        Unit, ///< The unit of the sensor.
+        Minimum, ///< The minimum value this sensor can have.
+        Maximum, ///< The maximum value this sensor can have.
+        Type, ///< The QVariant::Type of the sensor.
+        Value, ///< The value of the sensor.
+        FormattedValue, ///< A formatted string of the value of the sensor.
+        Color, ///< A color of the sensor, if sensorColors is set
+        UpdateInterval, ///< The time in milliseconds between each update of the sensor.
     };
     Q_ENUM(AdditionalRoles)
 
@@ -128,6 +121,10 @@ public:
     void setSensorColors(const QVariantMap &sensorColors);
     Q_SIGNAL void sensorColorsChanged();
 
+    QVariantMap sensorLabels() const;
+    void setSensorLabels(const QVariantMap &sensorLabels);
+    Q_SIGNAL void sensorLabelsChanged();
+
     int updateRateLimit() const;
     void setUpdateRateLimit(int newUpdateRateLimit);
     void resetUpdateRateLimit();
